import sys
import os
import inspect

# COMPILER SETUP
if sys.platform == "linux" or sys.platform == "linux2":
    try:
        os.system('module load gcc') 
        # If we're on a compute cluster, intel compilers might be loaded
    except:
        print("Module load errored, compilation may fail")
        pass


os.environ['GRAVITAS_ROOT'] = os.path.dirname(
    os.path.abspath(inspect.getsourcefile(lambda: 0))
)
sys.path.insert(0, os.environ['GRAVITAS_ROOT'])


from .lib import *
from ._grav import _grav


import numpy as np
from ._grav import _grav

_SUPPORTED_MODELS = {'EGM96': 360, 'GRGM360': 360, "MRO120F": 120}
_MAX_PTS = int(1e5)

def acceleration(position_ecef: np.ndarray, max_order: int, use_model: str = "EGM96") -> np.ndarray:
    if use_model not in _SUPPORTED_MODELS:
        raise NotImplementedError(f"Model {use_model} is not supported, it must be in: {', '._SUPPORTED_MODELS.keys()}")
    if _SUPPORTED_MODELS[use_model] < max_order:
        raise ValueError(f"The {use_model} model has coefficients to a maximum order of {_SUPPORTED_MODELS[use_model]}, {max_order} input")
    if position_ecef.shape[0] > _MAX_PTS:
        raise ValueError(f"Currently, gravitas is limited to 1e5 points per acceleration() call ({position_ecef.shape[0]} provided)")

    res = np.array(_grav(position_ecef, max_order, use_model)).reshape((-1,3))
    return res




from setuptools import setup, find_packages, Extension
import os
import numpy as np

_SOURCES = [os.path.join('gravitas', x) for x in os.listdir('gravitas') if '.c' == x[-2:]]
_INCDIR = ['gravitas', np.get_include()]
# _LIB_DIR
setup(
    name='gravitas',
    version='0.1.1',
    packages=find_packages(),
    license='GPL-2',
    long_description="""High-fidelity gravity fields for satellite propagation""",
    long_description_content_type='text/markdown',
    author="Liam Robinson",
    author_email="robin502@purdue.edu",
    install_requires=['numpy'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Operating System :: MacOS",
    ],
    ext_modules=[
        Extension(
            # the qualified name of the extension module to build
            'gravitas._grav',
            # the files to compile into our module relative to ``setup.py``
            sources=_SOURCES,
            include_dirs=_INCDIR
        ),
    ],
    include_package_data=True,  # Include non-Python files in packages
    zip_safe=False,  # Allow the package to be unzipped without modification
)